Module: Google::Apis::DatabasecenterV1beta

Defined in:
lib/google/apis/databasecenter_v1beta.rb,
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/service.rb,
lib/google/apis/databasecenter_v1beta/gem_version.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

Database Center API

Database Center offers a comprehensive, organization-wide platform for monitoring database fleet health across various products. It simplifies management and reduces risk by automatically aggregating and summarizing key health signals, removing the need for custom dashboards. The platform provides a unified view through its dashboard and API, enabling teams focused on reliability, compliance, security, cost, and administration to quickly identify and address relevant issues within their database fleets.

Defined Under Namespace

Classes: AdditionalDetail, Affiliation, AggregateFleetResponse, AggregateFleetRow, AggregateIssueStatsRequest, AggregateIssueStatsResponse, AggregateQueryStatsRequest, AggregateQueryStatsResponse, AutomatedBackupPolicyInfo, BackupDrConfig, BackupRunInfo, DatabaseCenterService, DatabaseResource, DatabaseResourceGroup, DatabaseResourceIssue, Date, DeletionProtectionInfo, DeltaDetails, Dimension, InefficientQueryInfo, IssueCount, IssueGroupStats, IssueStats, Label, Lineage, MachineConfig, MaintenanceInfo, MaintenanceRecommendationInfo, MetricData, Metrics, OutdatedMinorVersionInfo, Product, QueryDatabaseResourceGroupsRequest, QueryDatabaseResourceGroupsResponse, QueryIssuesRequest, QueryIssuesResponse, QueryMetrics, QueryProductsResponse, QueryStats, QueryStatsInfo, RecommendationInfo, RegulatoryStandard, ResourceDetails, ResourceId, ResourceMaintenanceDenySchedule, ResourceMaintenanceSchedule, ResourceSuspensionInfo, RetentionSettingsInfo, SccInfo, Signal, SignalFilter, SignalGroup, SignalProductsFilters, SignalTypeGroup, SubResource, Tag, TimeOfDay, TypedValue, UpcomingMaintenance

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-databasecenter_v1beta gem

"0.1.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.19.0"
REVISION =

Revision of the discovery document this client was generated from

"20260612"
VERSION =

Version of the Database Center API this client connects to. This is NOT the gem version.

'V1beta'
AUTH_CLOUD_PLATFORM =

See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.

'https://www.googleapis.com/auth/cloud-platform'