Class: Google::Apis::DatabasecenterV1beta::Affiliation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

Affiliation information of a resource

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Affiliation

Returns a new instance of Affiliation.



137
138
139
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 137

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#full_resource_nameString

Optional. Full resource name Corresponds to the JSON property fullResourceName

Returns:

  • (String)


123
124
125
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 123

def full_resource_name
  @full_resource_name
end

#lineagesArray<Google::Apis::DatabasecenterV1beta::Lineage>

Optional. Multiple lineages can be created from a resource. For example, a resource can be replicated to multiple target resources. In this case, there will be multiple lineages for the resource, one for each target resource. Corresponds to the JSON property lineages



130
131
132
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 130

def lineages
  @lineages
end

#resource_idString

Optional. resource id of affiliated resource Corresponds to the JSON property resourceId

Returns:

  • (String)


135
136
137
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 135

def resource_id
  @resource_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



142
143
144
145
146
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 142

def update!(**args)
  @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name)
  @lineages = args[:lineages] if args.key?(:lineages)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
end