Class: Google::Apis::DatabasecenterV1beta::AggregateIssueStatsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

AggregateIssueStatsRequest represents the input to the AggregateIssueStats method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AggregateIssueStatsRequest

Returns a new instance of AggregateIssueStatsRequest.



285
286
287
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 285

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#baseline_dateGoogle::Apis::DatabasecenterV1beta::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property baselineDate



255
256
257
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 255

def baseline_date
  @baseline_date
end

#filterString

Optional. The expression to filter resources. Supported fields are: full_resource_name, resource_type, container, product.type, product. engine, product.version, location, labels, issues, fields of availability_info, data_protection_info,'resource_name', etc. The expression is a list of zero or more restrictions combined via logical operators AND and OR. When AND and OR are both used in the expression, parentheses must be appropriately used to group the combinations. Example: location="us- east1" Example: container="projects/123" OR container="projects/456" Example: (container="projects/123" OR container="projects/456") AND location=" us-east1" Corresponds to the JSON property filter

Returns:

  • (String)


269
270
271
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 269

def filter
  @filter
end

#parentString

Required. Parent can be a project, a folder, or an organization. The search is limited to the resources within the scope. The allowed values are: * projects/PROJECT_ID (e.g., "projects/foo-bar") * projects/PROJECT_NUMBER ( e.g., "projects/12345678") * folders/FOLDER_NUMBER (e.g., "folders/1234567")

  • organizations/ORGANIZATION_NUMBER (e.g., "organizations/123456") Corresponds to the JSON property parent

Returns:

  • (String)


278
279
280
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 278

def parent
  @parent
end

#signal_type_groupsArray<Google::Apis::DatabasecenterV1beta::SignalTypeGroup>

Optional. Lists of signal types that are issues. Corresponds to the JSON property signalTypeGroups



283
284
285
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 283

def signal_type_groups
  @signal_type_groups
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



290
291
292
293
294
295
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 290

def update!(**args)
  @baseline_date = args[:baseline_date] if args.key?(:baseline_date)
  @filter = args[:filter] if args.key?(:filter)
  @parent = args[:parent] if args.key?(:parent)
  @signal_type_groups = args[:signal_type_groups] if args.key?(:signal_type_groups)
end