Class: Google::Apis::DatabasecenterV1beta::AggregateQueryStatsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

AggregateQueryStatsRequest represents the input to the AggregateQueryStats method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AggregateQueryStatsRequest

Returns a new instance of AggregateQueryStatsRequest.



383
384
385
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 383

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Optional. The expression to filter resources. Supported fields are: full_resource_name, resource_type, container, product.type, product. engine, product.version, location, labels, issues, fields of availability_info, data_protection_info,'resource_name', etc. The expression is a list of zero or more restrictions combined via logical operators AND and OR. When AND and OR are both used in the expression, parentheses must be appropriately used to group the combinations. Example: location="us- east1" Example: container="projects/123" OR container="projects/456" Example: (container="projects/123" OR container="projects/456") AND location=" us-east1" Additional specific fields for query stats are: metric_window, query_hash, normalized_query. Example: metric_window="LAST_ONE_DAY" ( Possible values for metric_window are: LAST_ONE_DAY, LAST_ONE_WEEK, LAST_TWO_WEEKS) Example: query_hash="12345678" Example: normalized_query=" SELECT * FROM table" Corresponds to the JSON property filter

Returns:

  • (String)


359
360
361
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 359

def filter
  @filter
end

#order_byString

Optional. The expression to order the results by. Example: order_by=" execution_count" Example: order_by="execution_count desc" Supported order by fields are execution_count, rows_processed, total_cpu_time, avg_cpu_time. Corresponds to the JSON property orderBy

Returns:

  • (String)


367
368
369
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 367

def order_by
  @order_by
end

#page_sizeFixnum

Optional. If unspecified, at most 100 query stats will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


373
374
375
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 373

def page_size
  @page_size
end

#page_tokenString

Optional. A page token, received from a previous AggregateQueryStatsRequest call. Provide this to retrieve the subsequent page. All parameters except page_token should match the parameters in the call that provided the page token. Corresponds to the JSON property pageToken

Returns:

  • (String)


381
382
383
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 381

def page_token
  @page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



388
389
390
391
392
393
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 388

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @order_by = args[:order_by] if args.key?(:order_by)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
end