Class: Google::Apis::DatabasecenterV1beta::AutomatedBackupPolicyInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

Automated backup policy signal info

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutomatedBackupPolicyInfo

Returns a new instance of AutomatedBackupPolicyInfo.



447
448
449
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 447

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_enabledBoolean Also known as: is_enabled?

Is automated policy enabled. Corresponds to the JSON property isEnabled

Returns:

  • (Boolean)


437
438
439
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 437

def is_enabled
  @is_enabled
end

#sub_resourceGoogle::Apis::DatabasecenterV1beta::SubResource

Sub resource details For Spanner/Bigtable instance certain data protection settings are at sub resource level like database/table. This message is used to capture such sub resource details. Corresponds to the JSON property subResource



445
446
447
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 445

def sub_resource
  @sub_resource
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



452
453
454
455
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 452

def update!(**args)
  @is_enabled = args[:is_enabled] if args.key?(:is_enabled)
  @sub_resource = args[:sub_resource] if args.key?(:sub_resource)
end