Class: Google::Apis::DatabasecenterV1beta::DatabaseResourceGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

DatabaseResourceGroup represents all resources that serve a common data set. It is considered notionally as a single entity, powered by any number of units of compute and storage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseResourceGroup

Returns a new instance of DatabaseResourceGroup.



696
697
698
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 696

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#root_resourcesArray<Google::Apis::DatabasecenterV1beta::DatabaseResource>

A database resource that serves as a root of the group of database resources. It is repeated just in case we have the concept of multiple roots in the future, however, it will only be populated with a single value for now. Corresponds to the JSON property rootResources



688
689
690
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 688

def root_resources
  @root_resources
end

#signal_groupsArray<Google::Apis::DatabasecenterV1beta::IssueCount>

The filtered signal groups and the count of issues associated with the resources that have been filtered in. Corresponds to the JSON property signalGroups



694
695
696
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 694

def signal_groups
  @signal_groups
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



701
702
703
704
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 701

def update!(**args)
  @root_resources = args[:root_resources] if args.key?(:root_resources)
  @signal_groups = args[:signal_groups] if args.key?(:signal_groups)
end