Class: Google::Apis::DatabasecenterV1beta::DeletionProtectionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

Deletion protection signal info for a database resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeletionProtectionInfo

Returns a new instance of DeletionProtectionInfo.



791
792
793
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 791

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deletion_protection_enabledBoolean Also known as: deletion_protection_enabled?

Is deletion protection enabled. Corresponds to the JSON property deletionProtectionEnabled

Returns:

  • (Boolean)


781
782
783
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 781

def deletion_protection_enabled
  @deletion_protection_enabled
end

#sub_resourceGoogle::Apis::DatabasecenterV1beta::SubResource

Sub resource details For Spanner/Bigtable instance certain data protection settings are at sub resource level like database/table. This message is used to capture such sub resource details. Corresponds to the JSON property subResource



789
790
791
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 789

def sub_resource
  @sub_resource
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



796
797
798
799
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 796

def update!(**args)
  @deletion_protection_enabled = args[:deletion_protection_enabled] if args.key?(:deletion_protection_enabled)
  @sub_resource = args[:sub_resource] if args.key?(:sub_resource)
end