Class: Google::Apis::DatabasecenterV1beta::Dimension

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

Dimension used to aggregate the fleet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Dimension

Returns a new instance of Dimension.



936
937
938
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 936

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containerString

Specifies where the resource is created. For Google Cloud resources, it is the full name of the project. Corresponds to the JSON property container

Returns:

  • (String)


838
839
840
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 838

def container
  @container
end

#editionString

The edition of the resource. Corresponds to the JSON property edition

Returns:

  • (String)


843
844
845
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 843

def edition
  @edition
end

#has_deny_maintenance_schedulesBoolean Also known as: has_deny_maintenance_schedules?

Whether the resource has deny maintenance schedules. Corresponds to the JSON property hasDenyMaintenanceSchedules

Returns:

  • (Boolean)


848
849
850
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 848

def has_deny_maintenance_schedules
  @has_deny_maintenance_schedules
end

#has_maintenance_scheduleBoolean Also known as: has_maintenance_schedule?

Whether the resource has a maintenance schedule. Corresponds to the JSON property hasMaintenanceSchedule

Returns:

  • (Boolean)


854
855
856
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 854

def has_maintenance_schedule
  @has_maintenance_schedule
end

#label_keyString

Label key of the resource. Corresponds to the JSON property labelKey

Returns:

  • (String)


860
861
862
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 860

def label_key
  @label_key
end

#label_sourceString

Label source of the resource. Corresponds to the JSON property labelSource

Returns:

  • (String)


865
866
867
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 865

def label_source
  @label_source
end

#label_valueString

Label value of the resource. Corresponds to the JSON property labelValue

Returns:

  • (String)


870
871
872
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 870

def label_value
  @label_value
end

#locationString

The location of the resources. It supports returning only regional locations in Google Cloud. Corresponds to the JSON property location

Returns:

  • (String)


876
877
878
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 876

def location
  @location
end

#management_typeString

The management type of the resource. Corresponds to the JSON property managementType

Returns:

  • (String)


881
882
883
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 881

def management_type
  @management_type
end

#product_engineString

Engine refers to underlying database binary running in an instance. Corresponds to the JSON property productEngine

Returns:

  • (String)


886
887
888
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 886

def product_engine
  @product_engine
end

#product_typeString

Type to identify a product Corresponds to the JSON property productType

Returns:

  • (String)


891
892
893
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 891

def product_type
  @product_type
end

#product_versionString

Version of the underlying database engine Corresponds to the JSON property productVersion

Returns:

  • (String)


896
897
898
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 896

def product_version
  @product_version
end

#resource_categoryString

The category of the resource. Corresponds to the JSON property resourceCategory

Returns:

  • (String)


901
902
903
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 901

def resource_category
  @resource_category
end

#resource_typeString

The type of resource defined according to the pattern: Service Name/Type. Ex: sqladmin.googleapis.com/Instance alloydb.googleapis.com/Cluster alloydb. googleapis.com/Instance spanner.googleapis.com/Instance Corresponds to the JSON property resourceType

Returns:

  • (String)


908
909
910
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 908

def resource_type
  @resource_type
end

#sub_resource_typeString

Subtype of the resource specified at creation time. Corresponds to the JSON property subResourceType

Returns:

  • (String)


913
914
915
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 913

def sub_resource_type
  @sub_resource_type
end

#tag_inheritedBoolean Also known as: tag_inherited?

Tag inheritance value of the resource. Corresponds to the JSON property tagInherited

Returns:

  • (Boolean)


918
919
920
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 918

def tag_inherited
  @tag_inherited
end

#tag_keyString

Tag key of the resource. Corresponds to the JSON property tagKey

Returns:

  • (String)


924
925
926
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 924

def tag_key
  @tag_key
end

#tag_sourceString

Tag source of the resource. Corresponds to the JSON property tagSource

Returns:

  • (String)


929
930
931
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 929

def tag_source
  @tag_source
end

#tag_valueString

Tag value of the resource. Corresponds to the JSON property tagValue

Returns:

  • (String)


934
935
936
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 934

def tag_value
  @tag_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 941

def update!(**args)
  @container = args[:container] if args.key?(:container)
  @edition = args[:edition] if args.key?(:edition)
  @has_deny_maintenance_schedules = args[:has_deny_maintenance_schedules] if args.key?(:has_deny_maintenance_schedules)
  @has_maintenance_schedule = args[:has_maintenance_schedule] if args.key?(:has_maintenance_schedule)
  @label_key = args[:label_key] if args.key?(:label_key)
  @label_source = args[:label_source] if args.key?(:label_source)
  @label_value = args[:label_value] if args.key?(:label_value)
  @location = args[:location] if args.key?(:location)
  @management_type = args[:management_type] if args.key?(:management_type)
  @product_engine = args[:product_engine] if args.key?(:product_engine)
  @product_type = args[:product_type] if args.key?(:product_type)
  @product_version = args[:product_version] if args.key?(:product_version)
  @resource_category = args[:resource_category] if args.key?(:resource_category)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @sub_resource_type = args[:sub_resource_type] if args.key?(:sub_resource_type)
  @tag_inherited = args[:tag_inherited] if args.key?(:tag_inherited)
  @tag_key = args[:tag_key] if args.key?(:tag_key)
  @tag_source = args[:tag_source] if args.key?(:tag_source)
  @tag_value = args[:tag_value] if args.key?(:tag_value)
end