Class: Google::Apis::DatabasecenterV1beta::IssueCount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

Count of issues for a group of signals.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IssueCount

Returns a new instance of IssueCount.



1025
1026
1027
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1025

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Title of a signal group corresponding to the request. Corresponds to the JSON property displayName

Returns:

  • (String)


1016
1017
1018
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1016

def display_name
  @display_name
end

#issue_countFixnum

The count of the number of issues associated with those resources that are explicitly filtered in by the filters present in the request. A signal is an issue when its SignalStatus field is set to SIGNAL_STATUS_ISSUE. Corresponds to the JSON property issueCount

Returns:

  • (Fixnum)


1023
1024
1025
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1023

def issue_count
  @issue_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1030
1031
1032
1033
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1030

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @issue_count = args[:issue_count] if args.key?(:issue_count)
end