Class: Google::Apis::DatabasecenterV1beta::IssueGroupStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

IssueGroupStats refers to stats for a particulare combination of relevant health issues of database resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IssueGroupStats

Returns a new instance of IssueGroupStats.



1078
1079
1080
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1078

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Database resource level health card name. This will corresponds to one of the requested input group names. Corresponds to the JSON property displayName

Returns:

  • (String)


1045
1046
1047
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1045

def display_name
  @display_name
end

#healthy_resource_groups_countFixnum

The number of resource groups from the total groups as defined above that are healthy with respect to all of the specified issues. Corresponds to the JSON property healthyResourceGroupsCount

Returns:

  • (Fixnum)


1051
1052
1053
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1051

def healthy_resource_groups_count
  @healthy_resource_groups_count
end

#healthy_resources_countFixnum

The number of resources from the total defined above in field total_resources_count that are healthy with respect to all of the specified issues. Corresponds to the JSON property healthyResourcesCount

Returns:

  • (Fixnum)


1058
1059
1060
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1058

def healthy_resources_count
  @healthy_resources_count
end

#issue_statsArray<Google::Apis::DatabasecenterV1beta::IssueStats>

List of issues stats containing count of resources having particular issue category. Corresponds to the JSON property issueStats



1064
1065
1066
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1064

def issue_stats
  @issue_stats
end

#resource_groups_countFixnum

Total count of the groups of resources returned by the filter that also have one or more resources for which any of the specified issues are applicable. Corresponds to the JSON property resourceGroupsCount

Returns:

  • (Fixnum)


1070
1071
1072
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1070

def resource_groups_count
  @resource_groups_count
end

#resources_countFixnum

Total count of resources returned by the filter for which any of the specified issues are applicable. Corresponds to the JSON property resourcesCount

Returns:

  • (Fixnum)


1076
1077
1078
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1076

def resources_count
  @resources_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1083
1084
1085
1086
1087
1088
1089
1090
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1083

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @healthy_resource_groups_count = args[:healthy_resource_groups_count] if args.key?(:healthy_resource_groups_count)
  @healthy_resources_count = args[:healthy_resources_count] if args.key?(:healthy_resources_count)
  @issue_stats = args[:issue_stats] if args.key?(:issue_stats)
  @resource_groups_count = args[:resource_groups_count] if args.key?(:resource_groups_count)
  @resources_count = args[:resources_count] if args.key?(:resources_count)
end