Class: Google::Apis::DatabasecenterV1beta::IssueStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

IssueStats holds stats for a particular signal category.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IssueStats

Returns a new instance of IssueStats.



1120
1121
1122
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1120

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delta_detailsGoogle::Apis::DatabasecenterV1beta::DeltaDetails

Captures the details of items that have increased or decreased in some bucket when compared to some point in history. It is currently used to capture the delta of resources that have been added or removed in the fleet as well as to capture the resources that have a change in Issue/Signal status. Corresponds to the JSON property deltaDetails



1103
1104
1105
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1103

def delta_details
  @delta_details
end

#issue_severityString

Severity of the issue. Corresponds to the JSON property issueSeverity

Returns:

  • (String)


1108
1109
1110
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1108

def issue_severity
  @issue_severity
end

#resource_countFixnum

Number of resources having issues of a given type. Corresponds to the JSON property resourceCount

Returns:

  • (Fixnum)


1113
1114
1115
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1113

def resource_count
  @resource_count
end

#signal_typeString

Type of signal which is an issue. Corresponds to the JSON property signalType

Returns:

  • (String)


1118
1119
1120
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1118

def signal_type
  @signal_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1125
1126
1127
1128
1129
1130
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1125

def update!(**args)
  @delta_details = args[:delta_details] if args.key?(:delta_details)
  @issue_severity = args[:issue_severity] if args.key?(:issue_severity)
  @resource_count = args[:resource_count] if args.key?(:resource_count)
  @signal_type = args[:signal_type] if args.key?(:signal_type)
end