Class: Google::Apis::DatabasecenterV1beta::MaintenanceInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

MaintenanceInfo to capture the maintenance details of database resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MaintenanceInfo

Returns a new instance of MaintenanceInfo.



1309
1310
1311
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1309

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_version_release_dateGoogle::Apis::DatabasecenterV1beta::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property currentVersionReleaseDate



1264
1265
1266
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1264

def current_version_release_date
  @current_version_release_date
end

#deny_maintenance_schedulesArray<Google::Apis::DatabasecenterV1beta::ResourceMaintenanceDenySchedule>

Optional. List of Deny maintenance period for the database resource. Corresponds to the JSON property denyMaintenanceSchedules



1269
1270
1271
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1269

def deny_maintenance_schedules
  @deny_maintenance_schedules
end

#maintenance_scheduleGoogle::Apis::DatabasecenterV1beta::ResourceMaintenanceSchedule

Maintenance window for the database resource. It specifies preferred time and day of the week and phase in some cases, when the maintenance can start. Corresponds to the JSON property maintenanceSchedule



1275
1276
1277
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1275

def maintenance_schedule
  @maintenance_schedule
end

#maintenance_versionString

Output only. Current Maintenance version of the database resource. Example: " MYSQL_8_0_41.R20250531.01_15" Corresponds to the JSON property maintenanceVersion

Returns:

  • (String)


1281
1282
1283
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1281

def maintenance_version
  @maintenance_version
end

#possible_failure_reasonsArray<String>

Output only. List of possible reasons why the maintenance is not completed. This is an optional field and is only populated if there are any reasons for failures recorded for the maintenance by DB Center. FAILURE maintenance status may not always have a failure reason. Corresponds to the JSON property possibleFailureReasons

Returns:

  • (Array<String>)


1289
1290
1291
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1289

def possible_failure_reasons
  @possible_failure_reasons
end

#previous_maintenance_versionString

Output only. Previous maintenance version of the database resource. Example: " MYSQL_8_0_41.R20250531.01_15". This is available once a minor version maintenance is complete on a database resource. Corresponds to the JSON property previousMaintenanceVersion

Returns:

  • (String)


1296
1297
1298
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1296

def previous_maintenance_version
  @previous_maintenance_version
end

#stateString

Output only. Resource maintenance state. This is to capture the current state of the maintenance. Corresponds to the JSON property state

Returns:

  • (String)


1302
1303
1304
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1302

def state
  @state
end

#upcoming_maintenanceGoogle::Apis::DatabasecenterV1beta::UpcomingMaintenance

Upcoming maintenance window for the database resource. Corresponds to the JSON property upcomingMaintenance



1307
1308
1309
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1307

def upcoming_maintenance
  @upcoming_maintenance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1314

def update!(**args)
  @current_version_release_date = args[:current_version_release_date] if args.key?(:current_version_release_date)
  @deny_maintenance_schedules = args[:deny_maintenance_schedules] if args.key?(:deny_maintenance_schedules)
  @maintenance_schedule = args[:maintenance_schedule] if args.key?(:maintenance_schedule)
  @maintenance_version = args[:maintenance_version] if args.key?(:maintenance_version)
  @possible_failure_reasons = args[:possible_failure_reasons] if args.key?(:possible_failure_reasons)
  @previous_maintenance_version = args[:previous_maintenance_version] if args.key?(:previous_maintenance_version)
  @state = args[:state] if args.key?(:state)
  @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance)
end