Class: Google::Apis::DatabasecenterV1beta::Metrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

Metrics represents the metrics for a database resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Metrics

Returns a new instance of Metrics.



1419
1420
1421
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1419

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_memory_used_bytesGoogle::Apis::DatabasecenterV1beta::MetricData

MetricData represents the metric data for a database resource. Corresponds to the JSON property currentMemoryUsedBytes



1377
1378
1379
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1377

def current_memory_used_bytes
  @current_memory_used_bytes
end

#current_storage_used_bytesGoogle::Apis::DatabasecenterV1beta::MetricData

MetricData represents the metric data for a database resource. Corresponds to the JSON property currentStorageUsedBytes



1382
1383
1384
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1382

def current_storage_used_bytes
  @current_storage_used_bytes
end

#node_countGoogle::Apis::DatabasecenterV1beta::MetricData

MetricData represents the metric data for a database resource. Corresponds to the JSON property nodeCount



1387
1388
1389
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1387

def node_count
  @node_count
end

#p95_cpu_utilizationGoogle::Apis::DatabasecenterV1beta::MetricData

MetricData represents the metric data for a database resource. Corresponds to the JSON property p95CpuUtilization



1392
1393
1394
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1392

def p95_cpu_utilization
  @p95_cpu_utilization
end

#p99_cpu_utilizationGoogle::Apis::DatabasecenterV1beta::MetricData

MetricData represents the metric data for a database resource. Corresponds to the JSON property p99CpuUtilization



1397
1398
1399
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1397

def p99_cpu_utilization
  @p99_cpu_utilization
end

#peak_memory_utilizationGoogle::Apis::DatabasecenterV1beta::MetricData

MetricData represents the metric data for a database resource. Corresponds to the JSON property peakMemoryUtilization



1402
1403
1404
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1402

def peak_memory_utilization
  @peak_memory_utilization
end

#peak_number_connectionsGoogle::Apis::DatabasecenterV1beta::MetricData

MetricData represents the metric data for a database resource. Corresponds to the JSON property peakNumberConnections



1407
1408
1409
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1407

def peak_number_connections
  @peak_number_connections
end

#peak_storage_utilizationGoogle::Apis::DatabasecenterV1beta::MetricData

MetricData represents the metric data for a database resource. Corresponds to the JSON property peakStorageUtilization



1412
1413
1414
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1412

def peak_storage_utilization
  @peak_storage_utilization
end

#processing_unit_countGoogle::Apis::DatabasecenterV1beta::MetricData

MetricData represents the metric data for a database resource. Corresponds to the JSON property processingUnitCount



1417
1418
1419
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1417

def processing_unit_count
  @processing_unit_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1424

def update!(**args)
  @current_memory_used_bytes = args[:current_memory_used_bytes] if args.key?(:current_memory_used_bytes)
  @current_storage_used_bytes = args[:current_storage_used_bytes] if args.key?(:current_storage_used_bytes)
  @node_count = args[:node_count] if args.key?(:node_count)
  @p95_cpu_utilization = args[:p95_cpu_utilization] if args.key?(:p95_cpu_utilization)
  @p99_cpu_utilization = args[:p99_cpu_utilization] if args.key?(:p99_cpu_utilization)
  @peak_memory_utilization = args[:peak_memory_utilization] if args.key?(:peak_memory_utilization)
  @peak_number_connections = args[:peak_number_connections] if args.key?(:peak_number_connections)
  @peak_storage_utilization = args[:peak_storage_utilization] if args.key?(:peak_storage_utilization)
  @processing_unit_count = args[:processing_unit_count] if args.key?(:processing_unit_count)
end