Class: Google::Apis::DatabasecenterV1beta::QueryDatabaseResourceGroupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

QueryDatabaseResourceGroupsResponse represents the response message containing a list of resource groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryDatabaseResourceGroupsResponse

Returns a new instance of QueryDatabaseResourceGroupsResponse.



1618
1619
1620
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1618

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1600
1601
1602
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1600

def next_page_token
  @next_page_token
end

#resource_groupsArray<Google::Apis::DatabasecenterV1beta::DatabaseResourceGroup>

List of database resource groups that pass the filter. Corresponds to the JSON property resourceGroups



1605
1606
1607
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1605

def resource_groups
  @resource_groups
end

#total_sizeFixnum

Output only. The total number of resource groups in the entire list. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


1610
1611
1612
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1610

def total_size
  @total_size
end

#unreachableArray<String>

Unordered list. List of unreachable regions from where data could not be retrieved. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1616
1617
1618
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1616

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1623
1624
1625
1626
1627
1628
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1623

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @resource_groups = args[:resource_groups] if args.key?(:resource_groups)
  @total_size = args[:total_size] if args.key?(:total_size)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end