Class: Google::Apis::DatabasecenterV1beta::QueryStats
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::QueryStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
QueryStats contains the stats for a particular combination of query_hash, query_string and resource_type.
Instance Attribute Summary collapse
-
#inefficient_query_info ⇒ Google::Apis::DatabasecenterV1beta::InefficientQueryInfo
Metadata about inefficient query signal info for a database resource.
-
#normalized_query ⇒ String
The query string is normalized query without any PII data.
-
#query_hash ⇒ String
The query hash of the query.
-
#query_metrics ⇒ Google::Apis::DatabasecenterV1beta::QueryMetrics
QueryMetrics contains the metrics related to the query execution.
-
#resource_ids ⇒ Array<Google::Apis::DatabasecenterV1beta::ResourceId>
The resource ids for which the query stats are collected.
-
#resource_type ⇒ String
The type of the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryStats
constructor
A new instance of QueryStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryStats
Returns a new instance of QueryStats.
1845 1846 1847 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1845 def initialize(**args) update!(**args) end |
Instance Attribute Details
#inefficient_query_info ⇒ Google::Apis::DatabasecenterV1beta::InefficientQueryInfo
Metadata about inefficient query signal info for a database resource.
Corresponds to the JSON property inefficientQueryInfo
1817 1818 1819 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1817 def inefficient_query_info @inefficient_query_info end |
#normalized_query ⇒ String
The query string is normalized query without any PII data.
Corresponds to the JSON property normalizedQuery
1822 1823 1824 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1822 def normalized_query @normalized_query end |
#query_hash ⇒ String
The query hash of the query.
Corresponds to the JSON property queryHash
1827 1828 1829 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1827 def query_hash @query_hash end |
#query_metrics ⇒ Google::Apis::DatabasecenterV1beta::QueryMetrics
QueryMetrics contains the metrics related to the query execution.
Corresponds to the JSON property queryMetrics
1832 1833 1834 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1832 def query_metrics @query_metrics end |
#resource_ids ⇒ Array<Google::Apis::DatabasecenterV1beta::ResourceId>
The resource ids for which the query stats are collected.
Corresponds to the JSON property resourceIds
1837 1838 1839 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1837 def resource_ids @resource_ids end |
#resource_type ⇒ String
The type of the resource. sqladmin.googleapis.com/Instance alloydb.googleapis.
com/Cluster alloydb.googleapis.com/Instance
Corresponds to the JSON property resourceType
1843 1844 1845 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1843 def resource_type @resource_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1850 def update!(**args) @inefficient_query_info = args[:inefficient_query_info] if args.key?(:inefficient_query_info) @normalized_query = args[:normalized_query] if args.key?(:normalized_query) @query_hash = args[:query_hash] if args.key?(:query_hash) @query_metrics = args[:query_metrics] if args.key?(:query_metrics) @resource_ids = args[:resource_ids] if args.key?(:resource_ids) @resource_type = args[:resource_type] if args.key?(:resource_type) end |