Class: Google::Apis::DatabasecenterV1beta::RecommendationInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

Info associated with recommendation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RecommendationInfo

Returns a new instance of RecommendationInfo.



1910
1911
1912
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#recommenderString

Name of recommendation. Examples: organizations/1234/locations/us-central1/ recommenders/google.cloudsql.instance.PerformanceRecommender/recommendations/ 9876 Corresponds to the JSON property recommender

Returns:

  • (String)


1891
1892
1893
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1891

def recommender
  @recommender
end

#recommender_idString

ID of recommender. Examples: "google.cloudsql.instance.PerformanceRecommender" Corresponds to the JSON property recommenderId

Returns:

  • (String)


1896
1897
1898
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1896

def recommender_id
  @recommender_id
end

#recommender_subtypeString

Contains an identifier for a subtype of recommendations produced for the same recommender. Subtype is a function of content and impact, meaning a new subtype might be added when significant changes to content or primary_impact.category are introduced. See the Recommenders section to see a list of subtypes for a given Recommender. Examples: For recommender = "google. cloudsql.instance.PerformanceRecommender", recommender_subtype can be " MYSQL_HIGH_NUMBER_OF_OPEN_TABLES_BEST_PRACTICE"/" POSTGRES_HIGH_TRANSACTION_ID_UTILIZATION_BEST_PRACTICE" Corresponds to the JSON property recommenderSubtype

Returns:

  • (String)


1908
1909
1910
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1908

def recommender_subtype
  @recommender_subtype
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1915
1916
1917
1918
1919
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1915

def update!(**args)
  @recommender = args[:recommender] if args.key?(:recommender)
  @recommender_id = args[:recommender_id] if args.key?(:recommender_id)
  @recommender_subtype = args[:recommender_subtype] if args.key?(:recommender_subtype)
end