Class: Google::Apis::DatabasecenterV1beta::RegulatoryStandard

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

Compliances associated with signals.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegulatoryStandard

Returns a new instance of RegulatoryStandard.



1936
1937
1938
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1936

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#standardString

Name of industry compliance standards, such as such as CIS, PCI, and OWASP. Corresponds to the JSON property standard

Returns:

  • (String)


1929
1930
1931
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1929

def standard
  @standard
end

#versionString

Version of the standard or benchmark, for example, 1.1. Corresponds to the JSON property version

Returns:

  • (String)


1934
1935
1936
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1934

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1941
1942
1943
1944
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1941

def update!(**args)
  @standard = args[:standard] if args.key?(:standard)
  @version = args[:version] if args.key?(:version)
end