Class: Google::Apis::DatabasecenterV1beta::ResourceDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

Capture the resource details for resources that are included in the delta counts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceDetails

Returns a new instance of ResourceDetails.



1973
1974
1975
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1973

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containerString

Specifies where the resource is created. For Google Cloud resources, it is the full name of the project. Corresponds to the JSON property container

Returns:

  • (String)


1956
1957
1958
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1956

def container
  @container
end

#full_resource_nameString

Full resource name of the resource. Corresponds to the JSON property fullResourceName

Returns:

  • (String)


1961
1962
1963
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1961

def full_resource_name
  @full_resource_name
end

#locationString

Location of the resource. Corresponds to the JSON property location

Returns:

  • (String)


1966
1967
1968
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1966

def location
  @location
end

#productGoogle::Apis::DatabasecenterV1beta::Product

Product specification for databasecenter resources. Corresponds to the JSON property product



1971
1972
1973
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1971

def product
  @product
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1978
1979
1980
1981
1982
1983
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1978

def update!(**args)
  @container = args[:container] if args.key?(:container)
  @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name)
  @location = args[:location] if args.key?(:location)
  @product = args[:product] if args.key?(:product)
end