Class: Google::Apis::DatabasecenterV1beta::ResourceId

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

ResourceId contains the identifier for a database resource, including the full resource name, resource type, and product.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceId

Returns a new instance of ResourceId.



2014
2015
2016
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2014

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#full_resource_nameString

The full resource name of the resource. Corresponds to the JSON property fullResourceName

Returns:

  • (String)


2001
2002
2003
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2001

def full_resource_name
  @full_resource_name
end

#productGoogle::Apis::DatabasecenterV1beta::Product

Product specification for databasecenter resources. Corresponds to the JSON property product



2006
2007
2008
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2006

def product
  @product
end

#resource_typeString

The type of the resource. sqladmin.googleapis.com/Instance alloydb.googleapis. com/Cluster alloydb.googleapis.com/Instance Corresponds to the JSON property resourceType

Returns:

  • (String)


2012
2013
2014
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2012

def resource_type
  @resource_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2019
2020
2021
2022
2023
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2019

def update!(**args)
  @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name)
  @product = args[:product] if args.key?(:product)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
end