Class: Google::Apis::DatabasecenterV1beta::ResourceMaintenanceDenySchedule
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::ResourceMaintenanceDenySchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
Deny maintenance period for the database resource. It specifies the time range during which the maintenance cannot start. This is configured by the customer.
Instance Attribute Summary collapse
-
#end_date ⇒ Google::Apis::DatabasecenterV1beta::Date
Represents a whole or partial calendar date, such as a birthday.
-
#start_date ⇒ Google::Apis::DatabasecenterV1beta::Date
Represents a whole or partial calendar date, such as a birthday.
-
#time ⇒ Google::Apis::DatabasecenterV1beta::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceMaintenanceDenySchedule
constructor
A new instance of ResourceMaintenanceDenySchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceMaintenanceDenySchedule
Returns a new instance of ResourceMaintenanceDenySchedule.
2055 2056 2057 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2055 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_date ⇒ Google::Apis::DatabasecenterV1beta::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property endDate
2034 2035 2036 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2034 def end_date @end_date end |
#start_date ⇒ Google::Apis::DatabasecenterV1beta::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property startDate
2046 2047 2048 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2046 def start_date @start_date end |
#time ⇒ Google::Apis::DatabasecenterV1beta::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property time
2053 2054 2055 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2053 def time @time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2060 2061 2062 2063 2064 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2060 def update!(**args) @end_date = args[:end_date] if args.key?(:end_date) @start_date = args[:start_date] if args.key?(:start_date) @time = args[:time] if args.key?(:time) end |