Class: Google::Apis::DatabasecenterV1beta::RetentionSettingsInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

Metadata about backup retention settings for a database resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RetentionSettingsInfo

Returns a new instance of RetentionSettingsInfo.



2157
2158
2159
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2157

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#duration_based_retentionString

Duration based retention period i.e. 172800 seconds (2 days) Corresponds to the JSON property durationBasedRetention

Returns:

  • (String)


2138
2139
2140
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2138

def duration_based_retention
  @duration_based_retention
end

#quantity_based_retentionFixnum

Number of backups that will be retained. Corresponds to the JSON property quantityBasedRetention

Returns:

  • (Fixnum)


2143
2144
2145
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2143

def quantity_based_retention
  @quantity_based_retention
end

#sub_resourceGoogle::Apis::DatabasecenterV1beta::SubResource

Sub resource details For Spanner/Bigtable instance certain data protection settings are at sub resource level like database/table. This message is used to capture such sub resource details. Corresponds to the JSON property subResource



2150
2151
2152
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2150

def sub_resource
  @sub_resource
end

#timestamp_based_retention_timeString

Timestamp based retention period i.e. till 2024-05-01T00:00:00Z Corresponds to the JSON property timestampBasedRetentionTime

Returns:

  • (String)


2155
2156
2157
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2155

def timestamp_based_retention_time
  @timestamp_based_retention_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2162
2163
2164
2165
2166
2167
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2162

def update!(**args)
  @duration_based_retention = args[:duration_based_retention] if args.key?(:duration_based_retention)
  @quantity_based_retention = args[:quantity_based_retention] if args.key?(:quantity_based_retention)
  @sub_resource = args[:sub_resource] if args.key?(:sub_resource)
  @timestamp_based_retention_time = args[:timestamp_based_retention_time] if args.key?(:timestamp_based_retention_time)
end