Class: Google::Apis::DatabasecenterV1beta::Signal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

Represents a signal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Signal

Returns a new instance of Signal.



2247
2248
2249
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2247

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_detailsArray<Google::Apis::DatabasecenterV1beta::AdditionalDetail>

Additional information related to the signal. In the case of composite signals, this field encapsulates details associated with granular signals, having a signal status of "ISSUE"; signals with a status of "OK" are not included. For granular signals, it encompasses information relevant to the signal, regardless of the signal status. Corresponds to the JSON property additionalDetails



2225
2226
2227
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2225

def additional_details
  @additional_details
end

#issue_create_timeString

Timestamp when the issue was created (when signal status is ISSUE). Corresponds to the JSON property issueCreateTime

Returns:

  • (String)


2230
2231
2232
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2230

def issue_create_time
  @issue_create_time
end

#issue_severityString

Severity of the issue. Corresponds to the JSON property issueSeverity

Returns:

  • (String)


2235
2236
2237
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2235

def issue_severity
  @issue_severity
end

#signal_statusString

Status of the signal. Corresponds to the JSON property signalStatus

Returns:

  • (String)


2240
2241
2242
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2240

def signal_status
  @signal_status
end

#signal_typeString

Type of the signal. Corresponds to the JSON property signalType

Returns:

  • (String)


2245
2246
2247
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2245

def signal_type
  @signal_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2252
2253
2254
2255
2256
2257
2258
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2252

def update!(**args)
  @additional_details = args[:additional_details] if args.key?(:additional_details)
  @issue_create_time = args[:issue_create_time] if args.key?(:issue_create_time)
  @issue_severity = args[:issue_severity] if args.key?(:issue_severity)
  @signal_status = args[:signal_status] if args.key?(:signal_status)
  @signal_type = args[:signal_type] if args.key?(:signal_type)
end