Class: Google::Apis::DatabasecenterV1beta::SignalGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

A group of signals and their counts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SignalGroup

Returns a new instance of SignalGroup.



2306
2307
2308
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2306

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Title of a signal group corresponding to the request. Corresponds to the JSON property displayName

Returns:

  • (String)


2291
2292
2293
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2291

def display_name
  @display_name
end

#issue_countFixnum

When applied to a DatabaseResource represents count of issues associated with the resource. A signal is an issue when its SignalStatus field is set to SIGNAL_STATUS_ISSUE. Corresponds to the JSON property issueCount

Returns:

  • (Fixnum)


2298
2299
2300
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2298

def issue_count
  @issue_count
end

#signalsArray<Google::Apis::DatabasecenterV1beta::Signal>

List of signals present in the group and associated with the resource. Only applies to a DatabaseResource. Corresponds to the JSON property signals



2304
2305
2306
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2304

def signals
  @signals
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2311
2312
2313
2314
2315
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2311

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @issue_count = args[:issue_count] if args.key?(:issue_count)
  @signals = args[:signals] if args.key?(:signals)
end