Class: Google::Apis::DatabasecenterV1beta::AggregateFleetResponse
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::AggregateFleetResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
The response message to aggregate a fleet by some group by fields.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token that can be sent as
page_tokento retrieve the next page. -
#resource_groups_total_count ⇒ Fixnum
Count of all resource groups in the fleet.
-
#resource_total_count ⇒ Fixnum
Count of all resources in the fleet.
-
#rows ⇒ Array<Google::Apis::DatabasecenterV1beta::AggregateFleetRow>
Represents a row grouped by the fields in the input.
-
#total_size ⇒ Fixnum
Output only.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AggregateFleetResponse
constructor
A new instance of AggregateFleetResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AggregateFleetResponse
Returns a new instance of AggregateFleetResponse.
185 186 187 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 185 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token that can be sent as page_token to retrieve the next page. If this
field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
157 158 159 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 157 def next_page_token @next_page_token end |
#resource_groups_total_count ⇒ Fixnum
Count of all resource groups in the fleet. This includes counts from all pages.
Corresponds to the JSON property resourceGroupsTotalCount
162 163 164 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 162 def resource_groups_total_count @resource_groups_total_count end |
#resource_total_count ⇒ Fixnum
Count of all resources in the fleet. This includes counts from all pages.
Corresponds to the JSON property resourceTotalCount
167 168 169 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 167 def resource_total_count @resource_total_count end |
#rows ⇒ Array<Google::Apis::DatabasecenterV1beta::AggregateFleetRow>
Represents a row grouped by the fields in the input.
Corresponds to the JSON property rows
172 173 174 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 172 def rows @rows end |
#total_size ⇒ Fixnum
Output only. The total number of rows in the entire list.
Corresponds to the JSON property totalSize
177 178 179 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 177 def total_size @total_size end |
#unreachable ⇒ Array<String>
Unordered list. List of unreachable regions from where data could not be
retrieved.
Corresponds to the JSON property unreachable
183 184 185 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 183 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
190 191 192 193 194 195 196 197 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 190 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resource_groups_total_count = args[:resource_groups_total_count] if args.key?(:resource_groups_total_count) @resource_total_count = args[:resource_total_count] if args.key?(:resource_total_count) @rows = args[:rows] if args.key?(:rows) @total_size = args[:total_size] if args.key?(:total_size) @unreachable = args[:unreachable] if args.key?(:unreachable) end |