Class: Google::Apis::DatabasecenterV1beta::AggregateFleetRow
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::AggregateFleetRow
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
Individual row grouped by a particular dimension.
Instance Attribute Summary collapse
-
#delta_details ⇒ Google::Apis::DatabasecenterV1beta::DeltaDetails
Captures the details of items that have increased or decreased in some bucket when compared to some point in history.
-
#dimension ⇒ Array<Google::Apis::DatabasecenterV1beta::Dimension>
Group by dimension.
-
#resource_groups_count ⇒ Fixnum
Number of resource groups that have a particular dimension.
-
#resources_count ⇒ Fixnum
Number of resources that have a particular dimension.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AggregateFleetRow
constructor
A new instance of AggregateFleetRow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AggregateFleetRow
Returns a new instance of AggregateFleetRow.
227 228 229 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 227 def initialize(**args) update!(**args) end |
Instance Attribute Details
#delta_details ⇒ Google::Apis::DatabasecenterV1beta::DeltaDetails
Captures the details of items that have increased or decreased in some bucket
when compared to some point in history. It is currently used to capture the
delta of resources that have been added or removed in the fleet as well as to
capture the resources that have a change in Issue/Signal status.
Corresponds to the JSON property deltaDetails
210 211 212 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 210 def delta_details @delta_details end |
#dimension ⇒ Array<Google::Apis::DatabasecenterV1beta::Dimension>
Group by dimension.
Corresponds to the JSON property dimension
215 216 217 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 215 def dimension @dimension end |
#resource_groups_count ⇒ Fixnum
Number of resource groups that have a particular dimension.
Corresponds to the JSON property resourceGroupsCount
220 221 222 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 220 def resource_groups_count @resource_groups_count end |
#resources_count ⇒ Fixnum
Number of resources that have a particular dimension.
Corresponds to the JSON property resourcesCount
225 226 227 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 225 def resources_count @resources_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
232 233 234 235 236 237 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 232 def update!(**args) @delta_details = args[:delta_details] if args.key?(:delta_details) @dimension = args[:dimension] if args.key?(:dimension) @resource_groups_count = args[:resource_groups_count] if args.key?(:resource_groups_count) @resources_count = args[:resources_count] if args.key?(:resources_count) end |