Class: Google::Apis::DatabasecenterV1beta::AggregateIssueStatsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::AggregateIssueStatsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
The response message containing one of more group of relevant health issues for database resources.
Instance Attribute Summary collapse
-
#issue_group_stats ⇒ Array<Google::Apis::DatabasecenterV1beta::IssueGroupStats>
List of issue group stats where each group contains stats for resources having a particular combination of relevant issues.
-
#total_resource_groups_count ⇒ Fixnum
Total count of the resource filtered in based on the user given filter.
-
#total_resources_count ⇒ Fixnum
Total count of the resources filtered in based on the user given filter.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AggregateIssueStatsResponse
constructor
A new instance of AggregateIssueStatsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AggregateIssueStatsResponse
Returns a new instance of AggregateIssueStatsResponse.
325 326 327 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 325 def initialize(**args) update!(**args) end |
Instance Attribute Details
#issue_group_stats ⇒ Array<Google::Apis::DatabasecenterV1beta::IssueGroupStats>
List of issue group stats where each group contains stats for resources having
a particular combination of relevant issues.
Corresponds to the JSON property issueGroupStats
307 308 309 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 307 def issue_group_stats @issue_group_stats end |
#total_resource_groups_count ⇒ Fixnum
Total count of the resource filtered in based on the user given filter.
Corresponds to the JSON property totalResourceGroupsCount
312 313 314 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 312 def total_resource_groups_count @total_resource_groups_count end |
#total_resources_count ⇒ Fixnum
Total count of the resources filtered in based on the user given filter.
Corresponds to the JSON property totalResourcesCount
317 318 319 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 317 def total_resources_count @total_resources_count end |
#unreachable ⇒ Array<String>
Unordered list. List of unreachable regions from where data could not be
retrieved.
Corresponds to the JSON property unreachable
323 324 325 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 323 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
330 331 332 333 334 335 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 330 def update!(**args) @issue_group_stats = args[:issue_group_stats] if args.key?(:issue_group_stats) @total_resource_groups_count = args[:total_resource_groups_count] if args.key?(:total_resource_groups_count) @total_resources_count = args[:total_resources_count] if args.key?(:total_resources_count) @unreachable = args[:unreachable] if args.key?(:unreachable) end |