Class: Google::Apis::DatabasecenterV1beta::AggregateQueryStatsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::AggregateQueryStatsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
The response message containing relevant query stats for database resources.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token that can be sent as
page_tokento retrieve the next page. -
#query_stats ⇒ Array<Google::Apis::DatabasecenterV1beta::QueryStatsInfo>
List of query stats where each group contains stats for resources having a particular combination of relevant query stats.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AggregateQueryStatsResponse
constructor
A new instance of AggregateQueryStatsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AggregateQueryStatsResponse
Returns a new instance of AggregateQueryStatsResponse.
418 419 420 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 418 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token that can be sent as page_token to retrieve the next page. If this
field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
404 405 406 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 404 def next_page_token @next_page_token end |
#query_stats ⇒ Array<Google::Apis::DatabasecenterV1beta::QueryStatsInfo>
List of query stats where each group contains stats for resources having a
particular combination of relevant query stats.
Corresponds to the JSON property queryStats
410 411 412 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 410 def query_stats @query_stats end |
#unreachable ⇒ Array<String>
Unordered list. List of unreachable regions from where data could not be
retrieved.
Corresponds to the JSON property unreachable
416 417 418 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 416 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
423 424 425 426 427 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 423 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @query_stats = args[:query_stats] if args.key?(:query_stats) @unreachable = args[:unreachable] if args.key?(:unreachable) end |