Class: Google::Apis::DatabasecenterV1beta::BackupRunInfo
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::BackupRunInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
Metadata about latest backup run state for a database resource.
Instance Attribute Summary collapse
-
#end_time ⇒ String
The time the backup operation completed.
-
#error_message ⇒ String
Additional information about the error encountered.
-
#operation_error_type ⇒ String
Optional.
-
#start_time ⇒ String
The time the backup operation started.
-
#state ⇒ String
Output only.
-
#sub_resource ⇒ Google::Apis::DatabasecenterV1beta::SubResource
Sub resource details For Spanner/Bigtable instance certain data protection settings are at sub resource level like database/table.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackupRunInfo
constructor
A new instance of BackupRunInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackupRunInfo
Returns a new instance of BackupRunInfo.
516 517 518 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 516 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
The time the backup operation completed.
Corresponds to the JSON property endTime
486 487 488 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 486 def end_time @end_time end |
#error_message ⇒ String
Additional information about the error encountered.
Corresponds to the JSON property errorMessage
491 492 493 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 491 def @error_message end |
#operation_error_type ⇒ String
Optional. OperationErrorType to expose specific error when backup operation of
database resource failed, that is state is FAILED.
Corresponds to the JSON property operationErrorType
497 498 499 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 497 def operation_error_type @operation_error_type end |
#start_time ⇒ String
The time the backup operation started.
Corresponds to the JSON property startTime
502 503 504 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 502 def start_time @start_time end |
#state ⇒ String
Output only. The state of this run.
Corresponds to the JSON property state
507 508 509 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 507 def state @state end |
#sub_resource ⇒ Google::Apis::DatabasecenterV1beta::SubResource
Sub resource details For Spanner/Bigtable instance certain data protection
settings are at sub resource level like database/table. This message is used
to capture such sub resource details.
Corresponds to the JSON property subResource
514 515 516 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 514 def sub_resource @sub_resource end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
521 522 523 524 525 526 527 528 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 521 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @error_message = args[:error_message] if args.key?(:error_message) @operation_error_type = args[:operation_error_type] if args.key?(:operation_error_type) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @sub_resource = args[:sub_resource] if args.key?(:sub_resource) end |