Class: Google::Apis::DatabasecenterV1beta::DatabaseResource
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::DatabaseResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
DatabaseResource represents every individually configured database unit representing compute and/or storage.
Instance Attribute Summary collapse
-
#affiliations ⇒ Array<Google::Apis::DatabasecenterV1beta::Affiliation>
Optional.
-
#backupdr_config ⇒ Google::Apis::DatabasecenterV1beta::BackupDrConfig
BackupDRConfig to capture the backup and disaster recovery details of database resource.
-
#child_resources ⇒ Array<Google::Apis::DatabasecenterV1beta::DatabaseResource>
List of children associated with a database group.
-
#container ⇒ String
Specifies where the resource is created.
-
#edition ⇒ String
The edition of the resource.
-
#full_resource_name ⇒ String
The full resource name, based on CAIS resource name format https://cloud.
-
#labels ⇒ Array<Google::Apis::DatabasecenterV1beta::Label>
Labels applied on the resource.
-
#location ⇒ String
The location of the resources.
-
#machine_config ⇒ Google::Apis::DatabasecenterV1beta::MachineConfig
MachineConfig describes the configuration of a machine specific to a Database Resource.
-
#maintenance_info ⇒ Google::Apis::DatabasecenterV1beta::MaintenanceInfo
MaintenanceInfo to capture the maintenance details of database resource.
-
#metrics ⇒ Google::Apis::DatabasecenterV1beta::Metrics
Metrics represents the metrics for a database resource.
-
#product ⇒ Google::Apis::DatabasecenterV1beta::Product
Product specification for databasecenter resources.
-
#resource_category ⇒ String
The category of the resource.
-
#resource_name ⇒ String
The name of the resource(The last part of the full resource name).
-
#resource_type ⇒ String
The type of resource defined according to the pattern:
Service Name/Type. -
#signal_groups ⇒ Array<Google::Apis::DatabasecenterV1beta::SignalGroup>
The list of signal groups and count of issues related to the resource.
-
#sub_resource_type ⇒ String
Subtype of the resource specified at creation time.
-
#tags ⇒ Array<Google::Apis::DatabasecenterV1beta::Tag>
Tags applied on the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DatabaseResource
constructor
A new instance of DatabaseResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DatabaseResource
Returns a new instance of DatabaseResource.
650 651 652 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 650 def initialize(**args) update!(**args) end |
Instance Attribute Details
#affiliations ⇒ Array<Google::Apis::DatabasecenterV1beta::Affiliation>
Optional. Affiliation details of the resource.
Corresponds to the JSON property affiliations
539 540 541 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 539 def affiliations @affiliations end |
#backupdr_config ⇒ Google::Apis::DatabasecenterV1beta::BackupDrConfig
BackupDRConfig to capture the backup and disaster recovery details of database
resource.
Corresponds to the JSON property backupdrConfig
545 546 547 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 545 def backupdr_config @backupdr_config end |
#child_resources ⇒ Array<Google::Apis::DatabasecenterV1beta::DatabaseResource>
List of children associated with a database group.
Corresponds to the JSON property childResources
550 551 552 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 550 def child_resources @child_resources end |
#container ⇒ String
Specifies where the resource is created. For Google Cloud resources, it is the
full name of the project.
Corresponds to the JSON property container
556 557 558 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 556 def container @container end |
#edition ⇒ String
The edition of the resource.
Corresponds to the JSON property edition
561 562 563 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 561 def edition @edition end |
#full_resource_name ⇒ String
The full resource name, based on CAIS resource name format https://cloud.
google.com/asset-inventory/docs/resource-name-format Example: //cloudsql.
googleapis.com/projects/project-number/instances/mysql-1 //cloudsql.
googleapis.com/projects/project-number/instances/postgres-1 //spanner.
googleapis.com/projects/project-number/instances/spanner-instance-1 //
alloydb.googleapis.com/projects/project-number/locations/us-central1/clusters/
c1 //alloydb.googleapis.com/projects/project-number/locations/us-central1/
clusters/c1/instances/i1
Corresponds to the JSON property fullResourceName
573 574 575 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 573 def full_resource_name @full_resource_name end |
#labels ⇒ Array<Google::Apis::DatabasecenterV1beta::Label>
Labels applied on the resource. The requirements for labels assigned to Google
Cloud resources may be found at https://cloud.google.com/resource-manager/docs/
labels-overview#requirements
Corresponds to the JSON property labels
580 581 582 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 580 def labels @labels end |
#location ⇒ String
The location of the resources. It supports returning only regional locations
in Google Cloud. These are of the form: "us-central1", "us-east1", etc. See
https://cloud.google.com/about/locations for a list of such regions.
Corresponds to the JSON property location
587 588 589 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 587 def location @location end |
#machine_config ⇒ Google::Apis::DatabasecenterV1beta::MachineConfig
MachineConfig describes the configuration of a machine specific to a Database
Resource.
Corresponds to the JSON property machineConfig
593 594 595 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 593 def machine_config @machine_config end |
#maintenance_info ⇒ Google::Apis::DatabasecenterV1beta::MaintenanceInfo
MaintenanceInfo to capture the maintenance details of database resource.
Corresponds to the JSON property maintenanceInfo
598 599 600 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 598 def maintenance_info @maintenance_info end |
#metrics ⇒ Google::Apis::DatabasecenterV1beta::Metrics
Metrics represents the metrics for a database resource.
Corresponds to the JSON property metrics
603 604 605 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 603 def metrics @metrics end |
#product ⇒ Google::Apis::DatabasecenterV1beta::Product
Product specification for databasecenter resources.
Corresponds to the JSON property product
608 609 610 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 608 def product @product end |
#resource_category ⇒ String
The category of the resource.
Corresponds to the JSON property resourceCategory
613 614 615 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 613 def resource_category @resource_category end |
#resource_name ⇒ String
The name of the resource(The last part of the full resource name). Example:
For full resource name - //cloudsql.googleapis.com/projects/project-number/
instances/mysql-1, resource name - mysql-1 For full resource name - //
cloudsql.googleapis.com/projects/project-number/instances/postgres-1 ,
resource name - postgres-1 Note: In some cases, there might be more than one
resource with the same resource name.
Corresponds to the JSON property resourceName
623 624 625 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 623 def resource_name @resource_name end |
#resource_type ⇒ String
The type of resource defined according to the pattern: Service Name/Type.
Ex: sqladmin.googleapis.com/Instance alloydb.googleapis.com/Cluster alloydb.
googleapis.com/Instance spanner.googleapis.com/Instance
Corresponds to the JSON property resourceType
630 631 632 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 630 def resource_type @resource_type end |
#signal_groups ⇒ Array<Google::Apis::DatabasecenterV1beta::SignalGroup>
The list of signal groups and count of issues related to the resource. Only
those signals which have been requested would be included.
Corresponds to the JSON property signalGroups
636 637 638 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 636 def signal_groups @signal_groups end |
#sub_resource_type ⇒ String
Subtype of the resource specified at creation time.
Corresponds to the JSON property subResourceType
641 642 643 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 641 def sub_resource_type @sub_resource_type end |
#tags ⇒ Array<Google::Apis::DatabasecenterV1beta::Tag>
Tags applied on the resource. The requirements for tags assigned to Google
Cloud resources may be found at https://cloud.google.com/resource-manager/docs/
tags/tags-overview
Corresponds to the JSON property tags
648 649 650 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 648 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 655 def update!(**args) @affiliations = args[:affiliations] if args.key?(:affiliations) @backupdr_config = args[:backupdr_config] if args.key?(:backupdr_config) @child_resources = args[:child_resources] if args.key?(:child_resources) @container = args[:container] if args.key?(:container) @edition = args[:edition] if args.key?(:edition) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @labels = args[:labels] if args.key?(:labels) @location = args[:location] if args.key?(:location) @machine_config = args[:machine_config] if args.key?(:machine_config) @maintenance_info = args[:maintenance_info] if args.key?(:maintenance_info) @metrics = args[:metrics] if args.key?(:metrics) @product = args[:product] if args.key?(:product) @resource_category = args[:resource_category] if args.key?(:resource_category) @resource_name = args[:resource_name] if args.key?(:resource_name) @resource_type = args[:resource_type] if args.key?(:resource_type) @signal_groups = args[:signal_groups] if args.key?(:signal_groups) @sub_resource_type = args[:sub_resource_type] if args.key?(:sub_resource_type) @tags = args[:tags] if args.key?(:tags) end |