Class: Google::Apis::DatabasecenterV1beta::DeltaDetails
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::DeltaDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
Captures the details of items that have increased or decreased in some bucket when compared to some point in history. It is currently used to capture the delta of resources that have been added or removed in the fleet as well as to capture the resources that have a change in Issue/Signal status.
Instance Attribute Summary collapse
-
#decreased_resources ⇒ Array<Google::Apis::DatabasecenterV1beta::ResourceDetails>
Details of resources that have decreased.
-
#increased_resources ⇒ Array<Google::Apis::DatabasecenterV1beta::ResourceDetails>
Details of resources that have increased.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeltaDetails
constructor
A new instance of DeltaDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeltaDetails
Returns a new instance of DeltaDetails.
819 820 821 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 819 def initialize(**args) update!(**args) end |
Instance Attribute Details
#decreased_resources ⇒ Array<Google::Apis::DatabasecenterV1beta::ResourceDetails>
Details of resources that have decreased.
Corresponds to the JSON property decreasedResources
812 813 814 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 812 def decreased_resources @decreased_resources end |
#increased_resources ⇒ Array<Google::Apis::DatabasecenterV1beta::ResourceDetails>
Details of resources that have increased.
Corresponds to the JSON property increasedResources
817 818 819 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 817 def increased_resources @increased_resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
824 825 826 827 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 824 def update!(**args) @decreased_resources = args[:decreased_resources] if args.key?(:decreased_resources) @increased_resources = args[:increased_resources] if args.key?(:increased_resources) end |