Class: Google::Apis::DatabasecenterV1beta::InefficientQueryInfo
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::InefficientQueryInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
Metadata about inefficient query signal info for a database resource.
Instance Attribute Summary collapse
-
#database ⇒ String
Name of the database where index is required.
-
#impacted_queries_count ⇒ Fixnum
Count of queries to be impacted if index is applied Corresponds to the JSON property
impactedQueriesCount. -
#sql_index_statement ⇒ String
SQL statement of the index.
-
#storage_cost_bytes ⇒ Fixnum
Cost of additional disk usage in bytes Corresponds to the JSON property
storageCostBytes. -
#table ⇒ String
Name of the table where index is required Corresponds to the JSON property
table.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InefficientQueryInfo
constructor
A new instance of InefficientQueryInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InefficientQueryInfo
Returns a new instance of InefficientQueryInfo.
995 996 997 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 995 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database ⇒ String
Name of the database where index is required. For example, "db1", which is the
name of the database present in the instance.
Corresponds to the JSON property database
972 973 974 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 972 def database @database end |
#impacted_queries_count ⇒ Fixnum
Count of queries to be impacted if index is applied
Corresponds to the JSON property impactedQueriesCount
977 978 979 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 977 def impacted_queries_count @impacted_queries_count end |
#sql_index_statement ⇒ String
SQL statement of the index. Based on the ddl type, this will be either CREATE
INDEX or DROP INDEX.
Corresponds to the JSON property sqlIndexStatement
983 984 985 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 983 def sql_index_statement @sql_index_statement end |
#storage_cost_bytes ⇒ Fixnum
Cost of additional disk usage in bytes
Corresponds to the JSON property storageCostBytes
988 989 990 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 988 def storage_cost_bytes @storage_cost_bytes end |
#table ⇒ String
Name of the table where index is required
Corresponds to the JSON property table
993 994 995 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 993 def table @table end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1000 1001 1002 1003 1004 1005 1006 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1000 def update!(**args) @database = args[:database] if args.key?(:database) @impacted_queries_count = args[:impacted_queries_count] if args.key?(:impacted_queries_count) @sql_index_statement = args[:sql_index_statement] if args.key?(:sql_index_statement) @storage_cost_bytes = args[:storage_cost_bytes] if args.key?(:storage_cost_bytes) @table = args[:table] if args.key?(:table) end |