Class: Google::Apis::DatabasecenterV1beta::Label
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::Label
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
Label is a key value pair applied to a resource.
Instance Attribute Summary collapse
-
#key ⇒ String
The key part of the label.
-
#source ⇒ String
The source of the Label.
-
#value ⇒ String
The value part of the label.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Label
constructor
A new instance of Label.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Label
Returns a new instance of Label.
1153 1154 1155 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1153 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
The key part of the label.
Corresponds to the JSON property key
1140 1141 1142 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1140 def key @key end |
#source ⇒ String
The source of the Label. Source is empty if the label is directly attached to
the resource and not inherited.
Corresponds to the JSON property source
1146 1147 1148 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1146 def source @source end |
#value ⇒ String
The value part of the label.
Corresponds to the JSON property value
1151 1152 1153 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1151 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1158 1159 1160 1161 1162 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1158 def update!(**args) @key = args[:key] if args.key?(:key) @source = args[:source] if args.key?(:source) @value = args[:value] if args.key?(:value) end |