Class: Google::Apis::DatabasecenterV1beta::MetricData
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::MetricData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
MetricData represents the metric data for a database resource.
Instance Attribute Summary collapse
-
#observation_time ⇒ String
The time the metric was observed in the metric source service.
-
#value ⇒ Google::Apis::DatabasecenterV1beta::TypedValue
TypedValue represents the value of the metric based on data type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetricData
constructor
A new instance of MetricData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetricData
Returns a new instance of MetricData.
1359 1360 1361 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1359 def initialize(**args) update!(**args) end |
Instance Attribute Details
#observation_time ⇒ String
The time the metric was observed in the metric source service.
Corresponds to the JSON property observationTime
1352 1353 1354 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1352 def observation_time @observation_time end |
#value ⇒ Google::Apis::DatabasecenterV1beta::TypedValue
TypedValue represents the value of the metric based on data type.
Corresponds to the JSON property value
1357 1358 1359 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1357 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1364 1365 1366 1367 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1364 def update!(**args) @observation_time = args[:observation_time] if args.key?(:observation_time) @value = args[:value] if args.key?(:value) end |