Class: Google::Apis::DatabasecenterV1beta::QueryDatabaseResourceGroupsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

QueryDatabaseResourceGroupsRequest is the request to get a list of database groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryDatabaseResourceGroupsRequest

Returns a new instance of QueryDatabaseResourceGroupsRequest.



1575
1576
1577
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1575

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#filterString

Optional. The expression to filter resources. The following fields are filterable: * full_resource_name * resource_type * container * product.type * product.engine * product.version * location * labels * resource_category * machine_config.cpu_count * machine_config.memory_size_bytes * machine_config. shard_count * resource_name * tags * backupdr_config.backupdr_managed * edition The expression is a list of zero or more restrictions combined via logical operators AND and OR. When AND and OR are both used in the expression, parentheses must be appropriately used to group the combinations. Example: location="us-east1" Example: container="projects/123" OR container= "projects/456" Example: (container="projects/123" OR container="projects/456" ) AND location="us-east1" Example: full_resource_name=~"test" Example: full_resource_name=~"test.*master" Corresponds to the JSON property filter

Returns:

  • (String)


1518
1519
1520
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1518

def filter
  @filter
end

#order_byString

Optional. A field that specifies the sort order of the results. The following fields are sortable: * full_resource_name * product.type * product.engine * product.version * container * issue_count * machine_config.vcpu_count * machine_config.memory_size_bytes * machine_config.shard_count * resource_name * issue_severity * signal_type * location * resource_type * instance_type * edition * metrics.p99_cpu_utilization * metrics.p95_cpu_utilization * metrics. current_storage_used_bytes * metrics.node_count * metrics. processing_unit_count * metrics.current_memory_used_bytes * metrics. peak_storage_utilization * metrics.peak_number_connections * metrics. peak_memory_utilization The default order is ascending. Add "DESC" after the field name to indicate descending order. Add "ASC" after the field name to indicate ascending order. It only supports a single field at a time. For example: order_by = "full_resource_name" sorts response in ascending order order_by = "full_resource_name DESC" sorts response in descending order order_by = "issue_count DESC" sorts response in descending order of count of all issues associated with a resource. More explicitly, order_by = " full_resource_name, product" is not supported. Corresponds to the JSON property orderBy

Returns:

  • (String)


1539
1540
1541
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1539

def order_by
  @order_by
end

#page_sizeFixnum

Optional. If unspecified, at most 50 resource groups will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


1545
1546
1547
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1545

def page_size
  @page_size
end

#page_tokenString

Optional. A page token, received from a previous QueryDatabaseResourceGroupsRequest call. Provide this to retrieve the subsequent page. All parameters except page_token should match the parameters in the call that provided the page page token. Corresponds to the JSON property pageToken

Returns:

  • (String)


1553
1554
1555
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1553

def page_token
  @page_token
end

#parentString

Required. Parent can be a project, a folder, or an organization. The search is limited to the resources within the scope. The allowed values are: * projects/PROJECT_ID (e.g., "projects/foo-bar") * projects/PROJECT_NUMBER ( e.g., "projects/12345678") * folders/FOLDER_NUMBER (e.g., "folders/1234567")

  • organizations/ORGANIZATION_NUMBER (e.g., "organizations/123456") Corresponds to the JSON property parent

Returns:

  • (String)


1562
1563
1564
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1562

def parent
  @parent
end

#signal_filtersArray<Google::Apis::DatabasecenterV1beta::SignalFilter>

Optional. Filters based on signals. The list will be ORed together and then ANDed with the filters field above. Corresponds to the JSON property signalFilters



1568
1569
1570
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1568

def signal_filters
  @signal_filters
end

#signal_type_groupsArray<Google::Apis::DatabasecenterV1beta::SignalTypeGroup>

Optional. Groups of signal types that are requested. Corresponds to the JSON property signalTypeGroups



1573
1574
1575
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1573

def signal_type_groups
  @signal_type_groups
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1580
1581
1582
1583
1584
1585
1586
1587
1588
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1580

def update!(**args)
  @filter = args[:filter] if args.key?(:filter)
  @order_by = args[:order_by] if args.key?(:order_by)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @parent = args[:parent] if args.key?(:parent)
  @signal_filters = args[:signal_filters] if args.key?(:signal_filters)
  @signal_type_groups = args[:signal_type_groups] if args.key?(:signal_type_groups)
end