Class: Google::Apis::DatabasecenterV1beta::QueryIssuesRequest
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::QueryIssuesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
QueryIssuesRequest is the request to get a list of issues.
Instance Attribute Summary collapse
-
#filter ⇒ String
Optional.
-
#order_by ⇒ String
Optional.
-
#page_size ⇒ Fixnum
Optional.
-
#page_token ⇒ String
Optional.
-
#parent ⇒ String
Required.
-
#signal_products_filters ⇒ Array<Google::Apis::DatabasecenterV1beta::SignalProductsFilters>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryIssuesRequest
constructor
A new instance of QueryIssuesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryIssuesRequest
Returns a new instance of QueryIssuesRequest.
1685 1686 1687 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1685 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
Optional. Supported fields are: 'product', location, issue_severity, 'tags'
, 'labels',
Corresponds to the JSON property filter
1646 1647 1648 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1646 def filter @filter end |
#order_by ⇒ String
Optional. Following fields are sortable: SignalType Product Location
IssueSeverity The default order is ascending. Add "DESC" after the field name
to indicate descending order. Add "ASC" after the field name to indicate
ascending order. It only supports a single field at a time.
Corresponds to the JSON property orderBy
1654 1655 1656 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1654 def order_by @order_by end |
#page_size ⇒ Fixnum
Optional. If unspecified, at most 50 issues will be returned. The maximum
value is 1000; values above 1000 will be coerced to 1000.
Corresponds to the JSON property pageSize
1660 1661 1662 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1660 def page_size @page_size end |
#page_token ⇒ String
Optional. A page token, received from a previous QueryIssues call. Provide
this to retrieve the subsequent page. All parameters except page size should
match the parameters used in the call that provided the page token.
Corresponds to the JSON property pageToken
1667 1668 1669 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1667 def page_token @page_token end |
#parent ⇒ String
Required. Parent can be a project, a folder, or an organization. The list is
limited to the one attached to resources within the scope that a user has
access to. The allowed values are: * projects/PROJECT_ID (e.g., "projects/
foo-bar") * projects/PROJECT_NUMBER (e.g., "projects/12345678") * folders/
FOLDER_NUMBER (e.g., "folders/1234567") * organizations/ORGANIZATION_NUMBER
(e.g., "organizations/123456")
Corresponds to the JSON property parent
1677 1678 1679 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1677 def parent @parent end |
#signal_products_filters ⇒ Array<Google::Apis::DatabasecenterV1beta::SignalProductsFilters>
Optional. Filters based on signal and product. The filter list will be ORed
across pairs and ANDed within a signal and products pair.
Corresponds to the JSON property signalProductsFilters
1683 1684 1685 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1683 def signal_products_filters @signal_products_filters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1690 1691 1692 1693 1694 1695 1696 1697 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1690 def update!(**args) @filter = args[:filter] if args.key?(:filter) @order_by = args[:order_by] if args.key?(:order_by) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @parent = args[:parent] if args.key?(:parent) @signal_products_filters = args[:signal_products_filters] if args.key?(:signal_products_filters) end |