Class: Google::Apis::DatabasecenterV1beta::QueryIssuesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::QueryIssuesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
QueryIssuesResponse is the response containing a list of issues.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token that can be sent as
page_tokento retrieve the next page. -
#resource_issues ⇒ Array<Google::Apis::DatabasecenterV1beta::DatabaseResourceIssue>
List of issues and resource details.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryIssuesResponse
constructor
A new instance of QueryIssuesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryIssuesResponse
Returns a new instance of QueryIssuesResponse.
1714 1715 1716 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1714 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token that can be sent as page_token to retrieve the next page. If this
field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
1701 1702 1703 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1701 def next_page_token @next_page_token end |
#resource_issues ⇒ Array<Google::Apis::DatabasecenterV1beta::DatabaseResourceIssue>
List of issues and resource details.
Corresponds to the JSON property resourceIssues
1706 1707 1708 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1706 def resource_issues @resource_issues end |
#unreachable ⇒ Array<String>
Unordered list. List of unreachable regions from where data could not be
retrieved.
Corresponds to the JSON property unreachable
1712 1713 1714 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1712 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1719 1720 1721 1722 1723 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1719 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resource_issues = args[:resource_issues] if args.key?(:resource_issues) @unreachable = args[:unreachable] if args.key?(:unreachable) end |