Class: Google::Apis::DatabasecenterV1beta::QueryMetrics
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::QueryMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
QueryMetrics contains the metrics related to the query execution.
Instance Attribute Summary collapse
-
#avg_cpu_time ⇒ String
The average execution period of the query across all runs.
-
#execution_count ⇒ Fixnum
The number of times the query was executed.
-
#metrics_window ⇒ String
The window over which the metrics are aggregated.
-
#rows_processed ⇒ Fixnum
The average number of rows processed by the query across all runs.
-
#total_cpu_time ⇒ String
The total CPU time consumed by the query across all runs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryMetrics
constructor
A new instance of QueryMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryMetrics
Returns a new instance of QueryMetrics.
1762 1763 1764 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1762 def initialize(**args) update!(**args) end |
Instance Attribute Details
#avg_cpu_time ⇒ String
The average execution period of the query across all runs.
Corresponds to the JSON property avgCpuTime
1740 1741 1742 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1740 def avg_cpu_time @avg_cpu_time end |
#execution_count ⇒ Fixnum
The number of times the query was executed.
Corresponds to the JSON property executionCount
1745 1746 1747 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1745 def execution_count @execution_count end |
#metrics_window ⇒ String
The window over which the metrics are aggregated.
Corresponds to the JSON property metricsWindow
1750 1751 1752 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1750 def metrics_window @metrics_window end |
#rows_processed ⇒ Fixnum
The average number of rows processed by the query across all runs.
Corresponds to the JSON property rowsProcessed
1755 1756 1757 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1755 def rows_processed @rows_processed end |
#total_cpu_time ⇒ String
The total CPU time consumed by the query across all runs.
Corresponds to the JSON property totalCpuTime
1760 1761 1762 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1760 def total_cpu_time @total_cpu_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1767 1768 1769 1770 1771 1772 1773 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1767 def update!(**args) @avg_cpu_time = args[:avg_cpu_time] if args.key?(:avg_cpu_time) @execution_count = args[:execution_count] if args.key?(:execution_count) @metrics_window = args[:metrics_window] if args.key?(:metrics_window) @rows_processed = args[:rows_processed] if args.key?(:rows_processed) @total_cpu_time = args[:total_cpu_time] if args.key?(:total_cpu_time) end |