Class: Google::Apis::DatabasecenterV1beta::QueryMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

QueryMetrics contains the metrics related to the query execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryMetrics

Returns a new instance of QueryMetrics.



1755
1756
1757
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1755

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#avg_cpu_timeString

The average execution period of the query across all runs. Corresponds to the JSON property avgCpuTime

Returns:

  • (String)


1733
1734
1735
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1733

def avg_cpu_time
  @avg_cpu_time
end

#execution_countFixnum

The number of times the query was executed. Corresponds to the JSON property executionCount

Returns:

  • (Fixnum)


1738
1739
1740
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1738

def execution_count
  @execution_count
end

#metrics_windowString

The window over which the metrics are aggregated. Corresponds to the JSON property metricsWindow

Returns:

  • (String)


1743
1744
1745
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1743

def metrics_window
  @metrics_window
end

#rows_processedFixnum

The average number of rows processed by the query across all runs. Corresponds to the JSON property rowsProcessed

Returns:

  • (Fixnum)


1748
1749
1750
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1748

def rows_processed
  @rows_processed
end

#total_cpu_timeString

The total CPU time consumed by the query across all runs. Corresponds to the JSON property totalCpuTime

Returns:

  • (String)


1753
1754
1755
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1753

def total_cpu_time
  @total_cpu_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1760
1761
1762
1763
1764
1765
1766
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1760

def update!(**args)
  @avg_cpu_time = args[:avg_cpu_time] if args.key?(:avg_cpu_time)
  @execution_count = args[:execution_count] if args.key?(:execution_count)
  @metrics_window = args[:metrics_window] if args.key?(:metrics_window)
  @rows_processed = args[:rows_processed] if args.key?(:rows_processed)
  @total_cpu_time = args[:total_cpu_time] if args.key?(:total_cpu_time)
end