Class: Google::Apis::DatabasecenterV1beta::QueryProductsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::QueryProductsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
QueryProductsResponse represents the response containing a list of products.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token that can be sent as
page_tokento retrieve the next page. -
#products ⇒ Array<Google::Apis::DatabasecenterV1beta::Product>
List of database products returned.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryProductsResponse
constructor
A new instance of QueryProductsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryProductsResponse
Returns a new instance of QueryProductsResponse.
1790 1791 1792 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1790 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token that can be sent as page_token to retrieve the next page. If this
field is omitted, there are no subsequent pages
Corresponds to the JSON property nextPageToken
1777 1778 1779 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1777 def next_page_token @next_page_token end |
#products ⇒ Array<Google::Apis::DatabasecenterV1beta::Product>
List of database products returned.
Corresponds to the JSON property products
1782 1783 1784 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1782 def products @products end |
#unreachable ⇒ Array<String>
Unordered list. List of unreachable regions from where data could not be
retrieved.
Corresponds to the JSON property unreachable
1788 1789 1790 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1788 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1795 1796 1797 1798 1799 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1795 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @products = args[:products] if args.key?(:products) @unreachable = args[:unreachable] if args.key?(:unreachable) end |