Class: Google::Apis::DatabasecenterV1beta::QueryStatsInfo
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::QueryStatsInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
QueryStatsInfo contains the aggregated and detailed query stats for a particular combination of relevant query stats for queries having same normalized query.
Instance Attribute Summary collapse
-
#aggregated_query_stats ⇒ Google::Apis::DatabasecenterV1beta::QueryStats
QueryStats contains the stats for a particular combination of query_hash, query_string and resource_type.
-
#query_stats ⇒ Array<Google::Apis::DatabasecenterV1beta::QueryStats>
List of query stats for the resources in the group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryStatsInfo
constructor
A new instance of QueryStatsInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryStatsInfo
Returns a new instance of QueryStatsInfo.
1878 1879 1880 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1878 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregated_query_stats ⇒ Google::Apis::DatabasecenterV1beta::QueryStats
QueryStats contains the stats for a particular combination of query_hash,
query_string and resource_type.
Corresponds to the JSON property aggregatedQueryStats
1870 1871 1872 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1870 def aggregated_query_stats @aggregated_query_stats end |
#query_stats ⇒ Array<Google::Apis::DatabasecenterV1beta::QueryStats>
List of query stats for the resources in the group. This stats is stats at
resource level for the resources having same normalized query.
Corresponds to the JSON property queryStats
1876 1877 1878 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1876 def query_stats @query_stats end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1883 1884 1885 1886 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1883 def update!(**args) @aggregated_query_stats = args[:aggregated_query_stats] if args.key?(:aggregated_query_stats) @query_stats = args[:query_stats] if args.key?(:query_stats) end |