Class: Google::Apis::DatabasecenterV1beta::QueryStatsInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

QueryStatsInfo contains the aggregated and detailed query stats for a particular combination of relevant query stats for queries having same normalized query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryStatsInfo

Returns a new instance of QueryStatsInfo.



1871
1872
1873
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1871

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregated_query_statsGoogle::Apis::DatabasecenterV1beta::QueryStats

QueryStats contains the stats for a particular combination of query_hash, query_string and resource_type. Corresponds to the JSON property aggregatedQueryStats



1863
1864
1865
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1863

def aggregated_query_stats
  @aggregated_query_stats
end

#query_statsArray<Google::Apis::DatabasecenterV1beta::QueryStats>

List of query stats for the resources in the group. This stats is stats at resource level for the resources having same normalized query. Corresponds to the JSON property queryStats



1869
1870
1871
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1869

def query_stats
  @query_stats
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1876
1877
1878
1879
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1876

def update!(**args)
  @aggregated_query_stats = args[:aggregated_query_stats] if args.key?(:aggregated_query_stats)
  @query_stats = args[:query_stats] if args.key?(:query_stats)
end