Class: Google::Apis::DatabasecenterV1beta::ResourceId
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::ResourceId
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
ResourceId contains the identifier for a database resource, including the full resource name, resource type, and product.
Instance Attribute Summary collapse
-
#full_resource_name ⇒ String
The full resource name of the resource.
-
#product ⇒ Google::Apis::DatabasecenterV1beta::Product
Product specification for databasecenter resources.
-
#resource_type ⇒ String
The type of the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceId
constructor
A new instance of ResourceId.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceId
Returns a new instance of ResourceId.
2007 2008 2009 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2007 def initialize(**args) update!(**args) end |
Instance Attribute Details
#full_resource_name ⇒ String
The full resource name of the resource.
Corresponds to the JSON property fullResourceName
1994 1995 1996 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1994 def full_resource_name @full_resource_name end |
#product ⇒ Google::Apis::DatabasecenterV1beta::Product
Product specification for databasecenter resources.
Corresponds to the JSON property product
1999 2000 2001 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 1999 def product @product end |
#resource_type ⇒ String
The type of the resource. sqladmin.googleapis.com/Instance alloydb.googleapis.
com/Cluster alloydb.googleapis.com/Instance
Corresponds to the JSON property resourceType
2005 2006 2007 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2005 def resource_type @resource_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2012 2013 2014 2015 2016 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2012 def update!(**args) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @product = args[:product] if args.key?(:product) @resource_type = args[:resource_type] if args.key?(:resource_type) end |