Class: Google::Apis::DatabasecenterV1beta::ResourceMaintenanceSchedule
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::ResourceMaintenanceSchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
Maintenance window for the database resource. It specifies preferred time and day of the week and phase in some cases, when the maintenance can start.
Instance Attribute Summary collapse
-
#day ⇒ String
Optional.
-
#phase ⇒ String
Optional.
-
#start_time ⇒ Google::Apis::DatabasecenterV1beta::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceMaintenanceSchedule
constructor
A new instance of ResourceMaintenanceSchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceMaintenanceSchedule
Returns a new instance of ResourceMaintenanceSchedule.
2093 2094 2095 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2093 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Optional. Preferred day of the week for maintenance, e.g. MONDAY, TUESDAY, etc.
Corresponds to the JSON property day
2075 2076 2077 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2075 def day @day end |
#phase ⇒ String
Optional. Phase of the maintenance window. This is to capture order of
maintenance. For example, for Cloud SQL resources, this can be used to capture
if the maintenance window is in Week1, Week2, Week5, etc. Non production
resources are usually part of early phase. For more details, refer to Cloud
SQL resources - https://cloud.google.com/sql/docs/mysql/maintenance
Corresponds to the JSON property phase
2084 2085 2086 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2084 def phase @phase end |
#start_time ⇒ Google::Apis::DatabasecenterV1beta::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
2091 2092 2093 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2091 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2098 2099 2100 2101 2102 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2098 def update!(**args) @day = args[:day] if args.key?(:day) @phase = args[:phase] if args.key?(:phase) @start_time = args[:start_time] if args.key?(:start_time) end |