Class: Google::Apis::DatabasecenterV1beta::Signal
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::Signal
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
Represents a signal.
Instance Attribute Summary collapse
-
#additional_details ⇒ Array<Google::Apis::DatabasecenterV1beta::AdditionalDetail>
Additional information related to the signal.
-
#issue_create_time ⇒ String
Timestamp when the issue was created (when signal status is ISSUE).
-
#issue_severity ⇒ String
Severity of the issue.
-
#signal_status ⇒ String
Status of the signal.
-
#signal_type ⇒ String
Type of the signal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Signal
constructor
A new instance of Signal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Signal
Returns a new instance of Signal.
2240 2241 2242 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2240 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_details ⇒ Array<Google::Apis::DatabasecenterV1beta::AdditionalDetail>
Additional information related to the signal. In the case of composite signals,
this field encapsulates details associated with granular signals, having a
signal status of "ISSUE"; signals with a status of "OK" are not included. For
granular signals, it encompasses information relevant to the signal,
regardless of the signal status.
Corresponds to the JSON property additionalDetails
2218 2219 2220 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2218 def additional_details @additional_details end |
#issue_create_time ⇒ String
Timestamp when the issue was created (when signal status is ISSUE).
Corresponds to the JSON property issueCreateTime
2223 2224 2225 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2223 def issue_create_time @issue_create_time end |
#issue_severity ⇒ String
Severity of the issue.
Corresponds to the JSON property issueSeverity
2228 2229 2230 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2228 def issue_severity @issue_severity end |
#signal_status ⇒ String
Status of the signal.
Corresponds to the JSON property signalStatus
2233 2234 2235 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2233 def signal_status @signal_status end |
#signal_type ⇒ String
Type of the signal.
Corresponds to the JSON property signalType
2238 2239 2240 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2238 def signal_type @signal_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2245 2246 2247 2248 2249 2250 2251 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2245 def update!(**args) @additional_details = args[:additional_details] if args.key?(:additional_details) @issue_create_time = args[:issue_create_time] if args.key?(:issue_create_time) @issue_severity = args[:issue_severity] if args.key?(:issue_severity) @signal_status = args[:signal_status] if args.key?(:signal_status) @signal_type = args[:signal_type] if args.key?(:signal_type) end |