Class: Google::Apis::DatabasecenterV1beta::SignalFilter
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::SignalFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
A filter for Signals. If signal_type is left unset, all signals should be
returned. For example, the following filter returns all issues. signal_filter:
signal_status: SIGNAL_STATUS_ISSUE; Another example, the following filter
returns issues of the given type: signal_filter: type:
SIGNAL_TYPE_NO_PROMOTABLE_REPLICA signal_status: ISSUE If signal_status is
left unset or set to SIGNAL_STATE_UNSPECIFIED, an error should be returned.
Instance Attribute Summary collapse
-
#signal_status ⇒ String
Optional.
-
#signal_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SignalFilter
constructor
A new instance of SignalFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SignalFilter
Returns a new instance of SignalFilter.
2273 2274 2275 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2273 def initialize(**args) update!(**args) end |
Instance Attribute Details
#signal_status ⇒ String
Optional. Represents the status of the Signal for which the filter is for.
Corresponds to the JSON property signalStatus
2266 2267 2268 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2266 def signal_status @signal_status end |
#signal_type ⇒ String
Optional. Represents the type of the Signal for which the filter is for.
Corresponds to the JSON property signalType
2271 2272 2273 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2271 def signal_type @signal_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2278 2279 2280 2281 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2278 def update!(**args) @signal_status = args[:signal_status] if args.key?(:signal_status) @signal_type = args[:signal_type] if args.key?(:signal_type) end |