Class: Google::Apis::DatabasecenterV1beta::SubResource
- Inherits:
-
Object
- Object
- Google::Apis::DatabasecenterV1beta::SubResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb
Overview
Sub resource details For Spanner/Bigtable instance certain data protection settings are at sub resource level like database/table. This message is used to capture such sub resource details.
Instance Attribute Summary collapse
-
#container ⇒ String
Specifies where the resource is created.
-
#full_resource_name ⇒ String
Optional.
-
#product ⇒ Google::Apis::DatabasecenterV1beta::Product
Product specification for databasecenter resources.
-
#resource_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubResource
constructor
A new instance of SubResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubResource
Returns a new instance of SubResource.
2403 2404 2405 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2403 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container ⇒ String
Specifies where the resource is created. For Google Cloud resources, it is the
full name of the project.
Corresponds to the JSON property container
2381 2382 2383 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2381 def container @container end |
#full_resource_name ⇒ String
Optional. Resource name associated with the sub resource where backup settings
are configured. E.g."//spanner.googleapis.com/projects/project1/instances/
inst1/databases/db1" for Spanner where backup retention is configured on
database within an instance OPTIONAL
Corresponds to the JSON property fullResourceName
2389 2390 2391 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2389 def full_resource_name @full_resource_name end |
#product ⇒ Google::Apis::DatabasecenterV1beta::Product
Product specification for databasecenter resources.
Corresponds to the JSON property product
2394 2395 2396 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2394 def product @product end |
#resource_type ⇒ String
Optional. Resource type associated with the sub resource where backup settings
are configured. E.g. "spanner.googleapis.com/Database" for Spanner where
backup retention is configured on database within an instance OPTIONAL
Corresponds to the JSON property resourceType
2401 2402 2403 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2401 def resource_type @resource_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2408 2409 2410 2411 2412 2413 |
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2408 def update!(**args) @container = args[:container] if args.key?(:container) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @product = args[:product] if args.key?(:product) @resource_type = args[:resource_type] if args.key?(:resource_type) end |