Class: Google::Apis::DatabasecenterV1beta::UpcomingMaintenance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/databasecenter_v1beta/classes.rb,
lib/google/apis/databasecenter_v1beta/representations.rb,
lib/google/apis/databasecenter_v1beta/representations.rb

Overview

Upcoming maintenance window for the database resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpcomingMaintenance

Returns a new instance of UpcomingMaintenance.



2548
2549
2550
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2548

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Output only. End time of the upcoming maintenance. This is only populated for an engine, if end time is public for the engine. Corresponds to the JSON property endTime

Returns:

  • (String)


2540
2541
2542
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2540

def end_time
  @end_time
end

#start_timeString

Output only. Start time of the upcoming maintenance. Start time is always populated when an upcoming maintenance is scheduled. Corresponds to the JSON property startTime

Returns:

  • (String)


2546
2547
2548
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2546

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2553
2554
2555
2556
# File 'lib/google/apis/databasecenter_v1beta/classes.rb', line 2553

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end